# README #

Kaipy is a Python package for analysis and visualization of simulation
results from a scientific software package Kaiju. Kaiju includes the
[Multiscale Atmosphere-Geospace Environment (MAGE)
](https://cgs.jhuapl.edu/Models/) model developed by the NASA
DRIVE [Center for Geospace Storms](https://cgs.jhuapl.edu/) as well as
other scientific software for simulation of heliospheric environments such
as planetary magnetospheres and the solar wind. 

### Documentation ###

Current documentation for this package available via our [Read The Docs website](https://kaipy-docs.readthedocs.io/en/latest/).

### License ###

Kaipy is distributed under the [BSD 3-Clause license](LICENSE.md).

### What is this repository for? ###

This repository provides access to the source code used
to implement the kaipy python package. The package is mostly commonly installed via
pip from [https://pypi.org/project/kaipy/](PyPi).

### How do I get set up? ###

```pip install kaipy```.


### Contribution guidelines ###

All contributions should be made by forking this repository and submitting a pull request.


### Who do I talk to? ###

For more information about the Kaipy project contact [Michael Wiltberger](mailto:wiltbemj@ucar.edu?subject=Kaipy).
